@@ -114,6 +114,7 @@ namespace Avro.Generic
         protected void WriteNull(object value, Encoder encoder)
         {
             if (value != null) throw TypeMismatch(value, "null", "null");
+            encoder.WriteNull();
         }
 
         /// <summary>
@@ -332,7 +333,7 @@ namespace Avro.Generic
 
         /// <summary>
         /// Creates a new <see cref="AvroException"/> and uses the provided parameters to build an
-        /// exception message indicathing there was a type mismatch.
+        /// exception message indicating there was a type mismatch.
         /// </summary>
         /// <param name="obj">Object whose type does not the expected type</param>
         /// <param name="schemaType">Schema that we tried to write against</param>
@@ -383,8 +384,8 @@ namespace Avro.Generic
 
             /// <summary>
             /// Returns the length of an array. The default implementation requires the object
-            /// to be an array of objects and returns its length. The defaul implementation
-            /// gurantees that EnsureArrayObject() has been called on the value before this
+            /// to be an array of objects and returns its length. The default implementation
+            /// guarantees that EnsureArrayObject() has been called on the value before this
             /// function is called.
             /// </summary>
             /// <param name="value">The object whose array length is required</param>
@@ -416,7 +417,7 @@ namespace Avro.Generic
             void EnsureMapObject(object value);
 
             /// <summary>
-            /// Returns the size of the map object. The default implementation gurantees that EnsureMapObject has been
+            /// Returns the size of the map object. The default implementation guarantees that EnsureMapObject has been
             /// successfully called with the given value. The default implementation requires the value
             /// to be an IDictionary&lt;string, object&gt; and returns the number of elements in it.
             /// </summary>
