@@ -24,6 +24,8 @@ using Avro.IO;
 using Avro.Specific;
 using Avro.Test.Specific;
 using System.Collections.Generic;
+using Avro.Generic;
+using Avro.Test.Generic;
 using Avro.Test.Specific.@return;
 
 #if !NETCOREAPP
@@ -270,6 +272,38 @@ namespace Avro.Test
             Assert.AreEqual(EnumType.DEFAULT, rec2.enumType);
         }
 
+        [TestCase(0L)]
+        [TestCase(100L)]
+        [TestCase(-100L)]
+        [TestCase(0.0)]
+        [TestCase(100.0)]
+        [TestCase(-100.0)]
+        public void TestDoubleLongUnion(object value)
+        {
+            var testRecord = new DoubleLongUnionRecord();
+            testRecord.Property = value;
+
+            // serialize
+            var stream = serialize(DoubleLongUnionRecord._SCHEMA, testRecord);
+
+            // deserialize
+            var rec2 = deserialize<DoubleLongUnionRecord>(stream, DoubleLongUnionRecord._SCHEMA, DoubleLongUnionRecord._SCHEMA);
+            Assert.AreEqual(value, rec2.Property);
+            Assert.AreEqual(value.GetType(), rec2.Property.GetType());
+        }
+
+        [TestCase(0)]
+        [TestCase(100)]
+        [TestCase(-100)]
+        [TestCase(0.0f)]
+        [TestCase(100.0f)]
+        [TestCase(-100.0f)]
+        [TestCase("0")]
+        [TestCase("100")]
+        public void TestDoubleLongUnionNoMatchException(object value)
+        {
+            Assert.Throws<AvroException>(() => serialize(DoubleLongUnionRecord._SCHEMA, new DoubleLongUnionRecord() { Property = value }));
+        }
 
         [Test]
         public void TestArrayWithReservedWords()
@@ -440,6 +474,43 @@ namespace Avro.Test
             Assert.AreEqual(0, dstRecord.UserMatrix[2].Count);
         }
 
+        private static void serializeGeneric<T>(string writerSchema, T actual, out Stream stream, out Schema ws)
+        {
+            var ms = new MemoryStream();
+            Encoder e = new BinaryEncoder(ms);
+            ws = Schema.Parse(writerSchema);
+            GenericWriter<T> w = new GenericWriter<T>(ws);
+            w.Write(actual, e);
+            ms.Flush();
+            ms.Position = 0;
+            stream = ms;
+        }
+        
+        [Test]
+        public void DeserializeToLogicalTypeWithDefault()
+        {
+            var writerSchemaString = @"{
+    ""type"": ""record"",
+    ""name"": ""RecordWithOptionalLogicalType"",
+    ""namespace"": ""Avro.Test.Specific.return"",
+    ""fields"": [      
+    ]}";
+
+            var writerSchema = Schema.Parse(writerSchemaString);
+
+            Stream stream;
+
+            serializeGeneric(writerSchemaString,
+                GenericTests.MkRecord(new object[] { }, (RecordSchema)writerSchema),
+                out stream,
+                out _);
+
+            RecordWithOptionalLogicalType output = deserialize<RecordWithOptionalLogicalType>(stream, writerSchema, RecordWithOptionalLogicalType._SCHEMA);
+
+            Assert.AreEqual(output.x, new DateTime(1970, 1, 11));
+
+        }
+        
         private static S deserialize<S>(Stream ms, Schema ws, Schema rs) where S : class, ISpecificRecord
         {
             long initialPos = ms.Position;
@@ -533,7 +604,7 @@ namespace Avro.Test
         }
 
         /// <summary>
-        /// Asserts that two lists are equal, delegating the work of comapring
+        /// Asserts that two lists are equal, delegating the work of comparing
         /// <see cref="ISpecificRecord"/> entries to
         /// <see cref="AssertSpecificRecordEqual(ISpecificRecord, ISpecificRecord)"/>.
         /// </summary>
