@@ -36,6 +36,7 @@ import org.apache.avro.io.DatumWriter;
 import org.apache.avro.specific.FixedSize;
 import org.apache.avro.specific.SpecificData;
 import org.apache.avro.util.ClassUtils;
+import org.apache.avro.util.MapUtil;
 
 import java.io.IOException;
 import java.lang.annotation.Annotation;
@@ -63,12 +64,16 @@ import java.util.List;
 import java.util.Map;
 import java.util.WeakHashMap;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 
 /** Utilities to use existing Java classes and interfaces via reflection. */
 public class ReflectData extends SpecificData {
 
   private static final String STRING_OUTER_PARENT_REFERENCE = "this$0";
 
+  /**
+   * Always false since custom coders are not available for {@link ReflectData}.
+   */
   @Override
   public boolean useCustomCoders() {
     return false;
@@ -422,16 +427,6 @@ public class ReflectData extends SpecificData {
     return null;
   }
 
-  /** @deprecated Replaced by {@link SpecificData#CLASS_PROP} */
-  @Deprecated
-  static final String CLASS_PROP = "java-class";
-  /** @deprecated Replaced by {@link SpecificData#KEY_CLASS_PROP} */
-  @Deprecated
-  static final String KEY_CLASS_PROP = "java-key-class";
-  /** @deprecated Replaced by {@link SpecificData#ELEMENT_PROP} */
-  @Deprecated
-  static final String ELEMENT_PROP = "java-element-class";
-
   private static final Map<String, Class> CLASS_CACHE = new ConcurrentHashMap<>();
 
   static Class getClassProp(Schema schema, String prop) {
@@ -569,7 +564,7 @@ public class ReflectData extends SpecificData {
       Package pkg2 = valueClass.getPackage();
 
       if (pkg1 != null && pkg1.getName().startsWith("java") && pkg2 != null && pkg2.getName().startsWith("java")) {
-        return NS_MAP_ARRAY_RECORD + keyClass.getSimpleName() + valueClass.getSimpleName();
+        return NS_MAP_ARRAY_RECORD + simpleName(keyClass) + simpleName(valueClass);
       }
     }
 
@@ -666,6 +661,9 @@ public class ReflectData extends SpecificData {
       return result;
     } else if (type instanceof Class) { // Class
       Class<?> c = (Class<?>) type;
+      while (c.isAnonymousClass()) {
+        c = c.getSuperclass();
+      }
       if (c.isPrimitive() || // primitives
           c == Void.class || c == Boolean.class || c == Integer.class || c == Long.class || c == Float.class
           || c == Double.class || c == Byte.class || c == Short.class || c == Character.class)
@@ -785,6 +783,18 @@ public class ReflectData extends SpecificData {
     return c.isAnnotationPresent(Stringable.class) || super.isStringable(c);
   }
 
+  private String simpleName(Class<?> c) {
+    String simpleName = null;
+    if (c != null) {
+      while (c.isAnonymousClass()) {
+        c = c.getSuperclass();
+      }
+      simpleName = c.getSimpleName();
+    }
+
+    return simpleName;
+  }
+
   private static final Schema THROWABLE_MESSAGE = makeNullable(Schema.create(Schema.Type.STRING));
 
   // if array element type is a class with a union annotation, note it
@@ -826,11 +836,11 @@ public class ReflectData extends SpecificData {
     }
   }
 
-  private static final Map<Class<?>, Field[]> FIELDS_CACHE = new ConcurrentHashMap<>();
+  private static final ConcurrentMap<Class<?>, Field[]> FIELDS_CACHE = new ConcurrentHashMap<>();
 
   // Return of this class and its superclasses to serialize.
   private static Field[] getCachedFields(Class<?> recordClass) {
-    return FIELDS_CACHE.computeIfAbsent(recordClass, rc -> getFields(rc, true));
+    return MapUtil.computeIfAbsent(FIELDS_CACHE, recordClass, rc -> getFields(rc, true));
   }
 
   private static Field[] getFields(Class<?> recordClass, boolean excludeJava) {
@@ -888,8 +898,7 @@ public class ReflectData extends SpecificData {
    */
   @Override
   public Protocol getProtocol(Class iface) {
-    Protocol protocol = new Protocol(iface.getSimpleName(),
-        iface.getPackage() == null ? "" : iface.getPackage().getName());
+    Protocol protocol = new Protocol(simpleName(iface), iface.getPackage() == null ? "" : iface.getPackage().getName());
     Map<String, Schema> names = new LinkedHashMap<>();
     Map<String, Message> messages = protocol.getMessages();
     Map<TypeVariable<?>, Type> genericTypeVariableMap = ReflectionUtil.resolveTypeVariables(iface);
