@@ -89,13 +89,18 @@ public class TestReadingWritingDataInEvolvedSchemas {
       .fields() //
       .name(FIELD_A).type().unionOf().stringType().and().bytesType().endUnion().noDefault() //
       .endRecord();
+
+  private static final Schema ENUM_AB = SchemaBuilder.enumeration("Enum1").symbols("A", "B");
+
   private static final Schema ENUM_AB_RECORD = SchemaBuilder.record(RECORD_A) //
       .fields() //
-      .name(FIELD_A).type().enumeration("Enum1").symbols("A", "B").noDefault() //
+      .name(FIELD_A).type(ENUM_AB).noDefault() //
       .endRecord();
+
+  private static final Schema ENUM_ABC = SchemaBuilder.enumeration("Enum1").symbols("A", "B", "C");
   private static final Schema ENUM_ABC_RECORD = SchemaBuilder.record(RECORD_A) //
       .fields() //
-      .name(FIELD_A).type().enumeration("Enum1").symbols("A", "B", "C").noDefault() //
+      .name(FIELD_A).type(ENUM_ABC).noDefault() //
       .endRecord();
   private static final Schema UNION_INT_RECORD = SchemaBuilder.record(RECORD_A) //
       .fields() //
@@ -310,7 +315,7 @@ public class TestReadingWritingDataInEvolvedSchemas {
   @Test
   public void enumRecordCanBeReadWithExtendedEnumSchema() throws Exception {
     Schema writer = ENUM_AB_RECORD;
-    Record record = defaultRecordWithSchema(writer, FIELD_A, new EnumSymbol(writer, "A"));
+    Record record = defaultRecordWithSchema(writer, FIELD_A, new EnumSymbol(ENUM_AB, "A"));
     byte[] encoded = encodeGenericBlob(record);
     Record decoded = decodeGenericBlob(ENUM_ABC_RECORD, writer, encoded);
     assertEquals("A", decoded.get(FIELD_A).toString());
@@ -319,7 +324,7 @@ public class TestReadingWritingDataInEvolvedSchemas {
   @Test
   public void enumRecordWithExtendedSchemaCanBeReadWithOriginalEnumSchemaIfOnlyOldValues() throws Exception {
     Schema writer = ENUM_ABC_RECORD;
-    Record record = defaultRecordWithSchema(writer, FIELD_A, new EnumSymbol(writer, "A"));
+    Record record = defaultRecordWithSchema(writer, FIELD_A, new EnumSymbol(ENUM_ABC, "A"));
     byte[] encoded = encodeGenericBlob(record);
     Record decoded = decodeGenericBlob(ENUM_AB_RECORD, writer, encoded);
     assertEquals("A", decoded.get(FIELD_A).toString());
@@ -330,7 +335,7 @@ public class TestReadingWritingDataInEvolvedSchemas {
     expectedException.expect(AvroTypeException.class);
     expectedException.expectMessage("No match for C");
     Schema writer = ENUM_ABC_RECORD;
-    Record record = defaultRecordWithSchema(writer, FIELD_A, new EnumSymbol(writer, "C"));
+    Record record = defaultRecordWithSchema(writer, FIELD_A, new EnumSymbol(ENUM_ABC, "C"));
     byte[] encoded = encodeGenericBlob(record);
     decodeGenericBlob(ENUM_AB_RECORD, writer, encoded);
   }
