@@ -18,9 +18,6 @@
 
 package org.apache.avro.generic;
 
-import static org.hamcrest.Matchers.is;
-import static org.junit.Assert.assertThat;
-
 import java.io.File;
 import java.io.IOException;
 import java.math.BigDecimal;
@@ -33,8 +30,10 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.UUID;
+
 import org.apache.avro.Conversion;
 import org.apache.avro.Conversions;
+import org.apache.avro.CustomType;
 import org.apache.avro.LogicalType;
 import org.apache.avro.LogicalTypes;
 import org.apache.avro.Schema;
@@ -44,20 +43,25 @@ import org.apache.avro.file.DataFileWriter;
 import org.apache.avro.file.FileReader;
 import org.apache.avro.io.DatumReader;
 import org.apache.avro.io.DatumWriter;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
+
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.is;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
 
 public class TestGenericLogicalTypes {
 
-  @Rule
-  public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir
+  public File temp;
 
   public static final GenericData GENERIC = new GenericData();
 
-  @BeforeClass
+  @BeforeAll
   public static void addLogicalTypes() {
     GENERIC.addLogicalTypeConversion(new Conversions.DecimalConversion());
     GENERIC.addLogicalTypeConversion(new Conversions.UUIDConversion());
@@ -75,7 +79,8 @@ public class TestGenericLogicalTypes {
     List<UUID> expected = Arrays.asList(u1, u2);
 
     File test = write(Schema.create(Schema.Type.STRING), u1.toString(), u2.toString());
-    Assert.assertEquals("Should convert Strings to UUIDs", expected, read(GENERIC.createDatumReader(uuidSchema), test));
+    Assertions.assertEquals(expected, read(GENERIC.createDatumReader(uuidSchema), test),
+        "Should convert Strings to UUIDs");
   }
 
   @Test
@@ -90,8 +95,8 @@ public class TestGenericLogicalTypes {
     List<String> expected = Arrays.asList(u1.toString(), u2.toString());
 
     File test = write(GENERIC, uuidSchema, u1, u2);
-    Assert.assertEquals("Should read UUIDs as Strings", expected,
-        read(GenericData.get().createDatumReader(stringSchema), test));
+    Assertions.assertEquals(expected, read(GenericData.get().createDatumReader(stringSchema), test),
+        "Should read UUIDs as Strings");
   }
 
   @Test
@@ -109,8 +114,8 @@ public class TestGenericLogicalTypes {
     List<String> expected = Arrays.asList(u1.toString(), u2.toString());
 
     File test = write(GENERIC, nullableUuidSchema, u1, u2);
-    Assert.assertEquals("Should read UUIDs as Strings", expected,
-        read(GenericData.get().createDatumReader(nullableStringSchema), test));
+    Assertions.assertEquals(expected, read(GenericData.get().createDatumReader(nullableStringSchema), test),
+        "Should read UUIDs as Strings");
   }
 
   @Test
@@ -130,8 +135,8 @@ public class TestGenericLogicalTypes {
     GenericFixed d2fixed = conversion.toFixed(d2, fixedSchema, decimal);
 
     File test = write(fixedSchema, d1fixed, d2fixed);
-    Assert.assertEquals("Should convert fixed to BigDecimals", expected,
-        read(GENERIC.createDatumReader(decimalSchema), test));
+    Assertions.assertEquals(expected, read(GENERIC.createDatumReader(decimalSchema), test),
+        "Should convert fixed to BigDecimals");
   }
 
   @Test
@@ -150,8 +155,8 @@ public class TestGenericLogicalTypes {
     List<GenericFixed> expected = Arrays.asList(d1fixed, d2fixed);
 
     File test = write(GENERIC, decimalSchema, d1, d2);
-    Assert.assertEquals("Should read BigDecimals as fixed", expected,
-        read(GenericData.get().createDatumReader(fixedSchema), test));
+    Assertions.assertEquals(expected, read(GenericData.get().createDatumReader(fixedSchema), test),
+        "Should read BigDecimals as fixed");
   }
 
   @Test
@@ -209,8 +214,8 @@ public class TestGenericLogicalTypes {
     ByteBuffer d2bytes = conversion.toBytes(d2, bytesSchema, decimal);
 
     File test = write(bytesSchema, d1bytes, d2bytes);
-    Assert.assertEquals("Should convert bytes to BigDecimals", expected,
-        read(GENERIC.createDatumReader(decimalSchema), test));
+    Assertions.assertEquals(expected, read(GENERIC.createDatumReader(decimalSchema), test),
+        "Should convert bytes to BigDecimals");
   }
 
   @Test
@@ -230,8 +235,8 @@ public class TestGenericLogicalTypes {
     List<ByteBuffer> expected = Arrays.asList(d1bytes, d2bytes);
 
     File test = write(GENERIC, decimalSchema, d1bytes, d2bytes);
-    Assert.assertEquals("Should read BigDecimals as bytes", expected,
-        read(GenericData.get().createDatumReader(bytesSchema), test));
+    Assertions.assertEquals(expected, read(GenericData.get().createDatumReader(bytesSchema), test),
+        "Should read BigDecimals as bytes");
   }
 
   private <D> List<D> read(DatumReader<D> reader, File file) throws IOException {
@@ -252,7 +257,7 @@ public class TestGenericLogicalTypes {
 
   @SuppressWarnings("unchecked")
   private <D> File write(GenericData model, Schema schema, D... data) throws IOException {
-    File file = temp.newFile();
+    File file = new File(temp, "out.avro");
     DatumWriter<D> writer = model.createDatumWriter(schema);
 
     try (DataFileWriter<D> fileWriter = new DataFileWriter<>(writer)) {
@@ -318,8 +323,8 @@ public class TestGenericLogicalTypes {
 
   private void checkCopy(Object original, Object copy, boolean notSame) {
     if (notSame)
-      Assert.assertNotSame(original, copy);
-    Assert.assertEquals(original, copy);
+      Assertions.assertNotSame(original, copy);
+    Assertions.assertEquals(original, copy);
   }
 
   @Test
@@ -339,8 +344,8 @@ public class TestGenericLogicalTypes {
     Long i2long = 0L;
 
     File test = write(longSchema, i1long, i2long);
-    Assert.assertEquals("Should convert long to LocalDateTime", expected,
-        read(GENERIC.createDatumReader(timestampSchema), test));
+    Assertions.assertEquals(expected, read(GENERIC.createDatumReader(timestampSchema), test),
+        "Should convert long to LocalDateTime");
   }
 
   @Test
@@ -359,8 +364,8 @@ public class TestGenericLogicalTypes {
     List<Long> expected = Arrays.asList(d1long, d2long);
 
     File test = write(GENERIC, timestampSchema, i1, i2);
-    Assert.assertEquals("Should read LocalDateTime as longs", expected,
-        read(GenericData.get().createDatumReader(timestampSchema), test));
+    Assertions.assertEquals(expected, read(GenericData.get().createDatumReader(timestampSchema), test),
+        "Should read LocalDateTime as longs");
   }
 
   @Test
@@ -380,8 +385,8 @@ public class TestGenericLogicalTypes {
     Long i2long = conversion.toLong(i2, longSchema, timestamp);
 
     File test = write(longSchema, i1long, i2long);
-    Assert.assertEquals("Should convert long to LocalDateTime", expected,
-        read(GENERIC.createDatumReader(timestampSchema), test));
+    Assertions.assertEquals(expected, read(GENERIC.createDatumReader(timestampSchema), test),
+        "Should convert long to LocalDateTime");
   }
 
   @Test
@@ -400,7 +405,56 @@ public class TestGenericLogicalTypes {
     List<Long> expected = Arrays.asList(d1long, d2long);
 
     File test = write(GENERIC, timestampSchema, i1, i2);
-    Assert.assertEquals("Should read LocalDateTime as longs", expected,
-        read(GenericData.get().createDatumReader(timestampSchema), test));
+    Assertions.assertEquals(expected, read(GenericData.get().createDatumReader(timestampSchema), test),
+        "Should read LocalDateTime as longs");
+  }
+
+  @Test
+  public void testReadAutomaticallyRegisteredUri() throws IOException {
+    Schema stringSchema = Schema.create(Schema.Type.STRING);
+    GenericData.setStringType(stringSchema, GenericData.StringType.String);
+    LogicalType customType = LogicalTypes.getCustomRegisteredTypes().get("custom").fromSchema(stringSchema);
+    Schema customTypeSchema = customType.addToSchema(Schema.create(Schema.Type.STRING));
+
+    CustomType ct1 = new CustomType("foo");
+    CustomType ct2 = new CustomType("bar");
+    List<CustomType> expected = Arrays.asList(ct1, ct2);
+
+    Conversion<CustomType> conversion = GENERIC.getConversionFor(customType);
+
+    // use the conversion directly instead of relying on the write side
+    CharSequence ct1String = conversion.toCharSequence(ct1, stringSchema, customType);
+    CharSequence ct2String = conversion.toCharSequence(ct2, stringSchema, customType);
+
+    File test = write(stringSchema, ct1String, ct2String);
+    assertEquals(expected, read(GENERIC.createDatumReader(customTypeSchema), test),
+        "Should convert string to CustomType");
+  }
+
+  @Test
+  public void testWriteAutomaticallyRegisteredUri() throws IOException {
+    Schema stringSchema = Schema.create(Schema.Type.STRING);
+    GenericData.setStringType(stringSchema, GenericData.StringType.String);
+    LogicalType customType = LogicalTypes.getCustomRegisteredTypes().get("custom").fromSchema(stringSchema);
+    Schema customTypeSchema = customType.addToSchema(Schema.create(Schema.Type.STRING));
+
+    CustomType ct1 = new CustomType("foo");
+    CustomType ct2 = new CustomType("bar");
+
+    Conversion<CustomType> conversion = GENERIC.getConversionFor(customType);
+
+    // use the conversion directly instead of relying on the write side
+    CharSequence ct1String = conversion.toCharSequence(ct1, stringSchema, customType);
+    CharSequence ct2String = conversion.toCharSequence(ct2, stringSchema, customType);
+    List<CharSequence> expected = Arrays.asList(ct1String, ct2String);
+
+    File test = write(GENERIC, customTypeSchema, ct1, ct2);
+
+    // Note that this test still cannot read strings using the logical type
+    // schema, as all GenericData instances have the logical type and the
+    // conversions loaded. That's why this final assert is slightly different.
+
+    assertEquals(expected, read(GenericData.get().createDatumReader(stringSchema), test),
+        "Should read CustomType as strings");
   }
 }
