@@ -33,11 +33,11 @@ var HANDSHAKE_RESPONSE_TYPE = protocols.HANDSHAKE_RESPONSE_TYPE;
 var createProtocol = protocols.createProtocol;
 
 
-suite('protocols', function () {
+describe('protocols', function () {
 
-  suite('Protocol', function () {
+  describe('Protocol', function () {
 
-    test('get name and types', function () {
+    it('get name and types', function () {
       var p = createProtocol({
         namespace: 'foo',
         protocol: 'HelloWorld',
@@ -70,20 +70,20 @@ suite('protocols', function () {
       assert.equal(p.getType('foo.Greeting').getName(true), 'record');
     });
 
-    test('missing message', function () {
+    it('missing message', function () {
       var ptcl = createProtocol({namespace: 'com.acme', protocol: 'Hello'});
       assert.throws(function () {
         ptcl.on('add', function () {});
       }, /unknown/);
     });
 
-    test('missing name', function () {
+    it('missing name', function () {
       assert.throws(function () {
         createProtocol({namespace: 'com.acme', messages: {}});
       });
     });
 
-    test('missing type', function () {
+    it('missing type', function () {
       assert.throws(function () {
         createProtocol({
           namespace: 'com.acme',
@@ -98,7 +98,7 @@ suite('protocols', function () {
       });
     });
 
-    test('get messages', function () {
+    it('get messages', function () {
       var ptcl;
       ptcl = createProtocol({protocol: 'Empty'});
       assert.deepEqual(ptcl.getMessages(), {});
@@ -116,7 +116,7 @@ suite('protocols', function () {
       assert(messages.ping !== undefined);
     });
 
-    test('create listener', function (done) {
+    it('create listener', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var transport = new stream.PassThrough();
       var ee = ptcl.createListener(transport, function (pending) {
@@ -126,14 +126,14 @@ suite('protocols', function () {
       ee.destroy();
     });
 
-    test('subprotocol', function () {
+    it('subprotocol', function () {
       var ptcl = createProtocol({namespace: 'com.acme', protocol: 'Hello'});
       var subptcl = ptcl.subprotocol();
       assert.strictEqual(subptcl._emitterResolvers, ptcl._emitterResolvers);
       assert.strictEqual(subptcl._listenerResolvers, ptcl._listenerResolvers);
     });
 
-    test('invalid emitter', function (done) {
+    it('invalid emitter', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       ptcl.emit('hi', {}, null, function (err) {
         assert(/invalid emitter/.test(err.string));
@@ -141,7 +141,7 @@ suite('protocols', function () {
       });
     });
 
-    test('inspect', function () {
+    it('inspect', function () {
       var p = createProtocol({
         namespace: 'hello',
         protocol: 'World',
@@ -151,11 +151,11 @@ suite('protocols', function () {
 
   });
 
-  suite('Message', function () {
+  describe('Message', function () {
 
     var Message = protocols.Message;
 
-    test('empty errors', function () {
+    it('empty errors', function () {
       var m = new Message('Hi', {
         request: [{name: 'greeting', type: 'string'}],
         response: 'int'
@@ -163,7 +163,7 @@ suite('protocols', function () {
       assert.deepEqual(m.errorType.toString(), '["string"]');
     });
 
-    test('missing response', function () {
+    it('missing response', function () {
       assert.throws(function () {
         new Message('Hi', {
           request: [{name: 'greeting', type: 'string'}]
@@ -171,7 +171,7 @@ suite('protocols', function () {
       });
     });
 
-    test('invalid one-way', function () {
+    it('invalid one-way', function () {
       // Non-null response.
       assert.throws(function () {
         new Message('Hi', {
@@ -193,11 +193,11 @@ suite('protocols', function () {
 
   });
 
-  suite('MessageDecoder', function () {
+  describe('MessageDecoder', function () {
 
     var MessageDecoder = protocols.streams.MessageDecoder;
 
-    test('ok', function (done) {
+    it('ok', function (done) {
       var parts = [
         Buffer.from([0, 1]),
         Buffer.from([2]),
@@ -218,7 +218,7 @@ suite('protocols', function () {
       readable.pipe(new MessageDecoder()).pipe(writable);
     });
 
-    test('trailing data', function (done) {
+    it('trailing data', function (done) {
       var parts = [
         Buffer.from([0, 1]),
         Buffer.from([2]),
@@ -237,7 +237,7 @@ suite('protocols', function () {
         .pipe(writable);
     });
 
-    test('empty', function (done) {
+    it('empty', function (done) {
       var readable = createReadableStream([], true);
       readable
         .pipe(new MessageDecoder(true))
@@ -246,15 +246,15 @@ suite('protocols', function () {
 
   });
 
-  suite('MessageEncoder', function () {
+  describe('MessageEncoder', function () {
 
     var MessageEncoder = protocols.streams.MessageEncoder;
 
-    test('invalid frame size', function () {
+    it('invalid frame size', function () {
       assert.throws(function () { new MessageEncoder(); });
     });
 
-    test('ok', function (done) {
+    it('ok', function (done) {
       var messages = [
         Buffer.from([0, 1]),
         Buffer.from([2])
@@ -277,7 +277,7 @@ suite('protocols', function () {
         });
     });
 
-    test('all zeros', function (done) {
+    it('all zeros', function (done) {
       var messages = [Buffer.from([0, 0, 0, 0])];
       var frames = [];
       var readable = createReadableStream(messages, true);
@@ -294,7 +294,7 @@ suite('protocols', function () {
         });
     });
 
-    test('short frame size', function (done) {
+    it('short frame size', function (done) {
       var messages = [
         Buffer.from([0, 1, 2]),
         Buffer.from([2])
@@ -319,9 +319,9 @@ suite('protocols', function () {
 
   });
 
-  suite('StatefulEmitter', function () {
+  describe('StatefulEmitter', function () {
 
-    test('ok handshake', function (done) {
+    it('ok handshake', function (done) {
       var buf = HANDSHAKE_RESPONSE_TYPE.toBuffer({match: 'BOTH'});
       var bufs = [];
       var ptcl = createProtocol({protocol: 'Empty'});
@@ -345,7 +345,7 @@ suite('protocols', function () {
         });
     });
 
-    test('no server match handshake', function (done) {
+    it('no server match handshake', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var resBufs = [
         {
@@ -372,7 +372,7 @@ suite('protocols', function () {
         });
     });
 
-    test('incompatible protocol', function (done) {
+    it('incompatible protocol', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var hash = Buffer.alloc(16); // Pretend the hash was different.
       var resBufs = [
@@ -400,7 +400,7 @@ suite('protocols', function () {
         });
     });
 
-    test('handshake error', function (done) {
+    it('handshake error', function (done) {
       var resBufs = [
         Buffer.from([4, 0, 0]), // Invalid handshakes.
         Buffer.from([4, 0, 0])
@@ -418,7 +418,7 @@ suite('protocols', function () {
         });
     });
 
-    test('orphan response', function (done) {
+    it('orphan response', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var idType = protocols.IdType.createMetadataType();
       var resBufs = [
@@ -437,7 +437,7 @@ suite('protocols', function () {
         });
     });
 
-    test('ended readable', function (done) {
+    it('ended readable', function (done) {
       var bufs = [];
       var ptcl = createProtocol({protocol: 'Empty'});
       ptcl.createEmitter(createTransport([], bufs))
@@ -447,7 +447,7 @@ suite('protocols', function () {
         });
     });
 
-    test('interrupted', function (done) {
+    it('interrupted', function (done) {
       var ptcl = createProtocol({
         protocol: 'Empty',
         messages: {
@@ -473,7 +473,7 @@ suite('protocols', function () {
       }
     });
 
-    test('missing client message', function (done) {
+    it('missing client message', function (done) {
       var ptcl1 = createProtocol({
         protocol: 'Ping',
         messages: {
@@ -496,7 +496,7 @@ suite('protocols', function () {
       });
     });
 
-    test('missing server message', function (done) {
+    it('missing server message', function (done) {
       var ptcl1 = createProtocol({
         protocol: 'Ping',
         messages: {
@@ -513,7 +513,7 @@ suite('protocols', function () {
         });
     });
 
-    test('trailing data', function (done) {
+    it('trailing data', function (done) {
       var ptcl = createProtocol({
         protocol: 'Ping',
         messages: {
@@ -529,7 +529,7 @@ suite('protocols', function () {
       transports[0].readable.end(Buffer.from([2, 3]));
     });
 
-    test('invalid metadata', function (done) {
+    it('invalid metadata', function (done) {
       var ptcl = createProtocol({
         protocol: 'Ping',
         messages: {
@@ -549,7 +549,7 @@ suite('protocols', function () {
         });
     });
 
-    test('invalid response', function (done) {
+    it('invalid response', function (done) {
       var ptcl = createProtocol({
         protocol: 'Ping',
         messages: {
@@ -577,7 +577,7 @@ suite('protocols', function () {
         });
     });
 
-    test('one way', function (done) {
+    it('one way', function (done) {
       var beats = 0;
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
@@ -599,9 +599,9 @@ suite('protocols', function () {
 
   });
 
-  suite('StatelessEmitter', function () {
+  describe('StatelessEmitter', function () {
 
-    test('interrupted before response data', function (done) {
+    it('interrupted before response data', function (done) {
       var ptcl = createProtocol({
         protocol: 'Ping',
         messages: {ping: {request: [], response: 'boolean'}}
@@ -623,9 +623,9 @@ suite('protocols', function () {
 
   });
 
-  suite('StatefulListener', function () {
+  describe('StatefulListener', function () {
 
-    test('end readable', function (done) {
+    it('end readable', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var transports = createPassthroughTransports();
       ptcl.createListener(transports[0])
@@ -636,7 +636,7 @@ suite('protocols', function () {
       transports[0].readable.end();
     });
 
-    test('finish writable', function (done) {
+    it('finish writable', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var transports = createPassthroughTransports();
       ptcl.createListener(transports[0])
@@ -647,7 +647,7 @@ suite('protocols', function () {
       transports[0].writable.end();
     });
 
-    test('invalid handshake', function (done) {
+    it('invalid handshake', function (done) {
       var ptcl = createProtocol({protocol: 'Empty'});
       var transport = createTransport(
         [Buffer.from([4])], // Invalid handshake.
@@ -661,7 +661,7 @@ suite('protocols', function () {
         });
     });
 
-    test('missing server message', function (done) {
+    it('missing server message', function (done) {
       var ptcl1 = createProtocol({protocol: 'Empty'});
       var ptcl2 = createProtocol({
         protocol: 'Heartbeat',
@@ -687,7 +687,7 @@ suite('protocols', function () {
         });
     });
 
-    test('invalid metadata', function (done) {
+    it('invalid metadata', function (done) {
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
         messages: {beat: {request: [], response: 'boolean'}}
@@ -707,7 +707,7 @@ suite('protocols', function () {
         });
     });
 
-    test('unknown message', function (done) {
+    it('unknown message', function (done) {
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
         messages: {beat: {request: [], response: 'boolean'}}
@@ -746,7 +746,7 @@ suite('protocols', function () {
         });
     });
 
-    test('invalid request', function (done) {
+    it('invalid request', function (done) {
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
         messages: {beat: {
@@ -787,7 +787,7 @@ suite('protocols', function () {
         });
     });
 
-    test('destroy', function (done) {
+    it('destroy', function (done) {
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
         messages: {beat: {request: [], response: 'boolean'}}
@@ -809,9 +809,9 @@ suite('protocols', function () {
 
   });
 
-  suite('StatelessListener', function () {
+  describe('StatelessListener', function () {
 
-    test('unknown message', function (done) {
+    it('unknown message', function (done) {
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
         messages: {beat: {request: [], response: 'boolean'}}
@@ -850,7 +850,7 @@ suite('protocols', function () {
       ]));
     });
 
-    test('late writable', function (done) {
+    it('late writable', function (done) {
       var ptcl = createProtocol({
         protocol: 'Heartbeat',
         messages: {beat: {request: [], response: 'boolean'}}
@@ -876,9 +876,9 @@ suite('protocols', function () {
 
   });
 
-  suite('emit', function () {
+  describe('emit', function () {
 
-    suite('stateful', function () {
+    describe('stateful', function () {
 
       run(function (emitterPtcl, listenerPtcl, cb) {
         var pt1 = new stream.PassThrough();
@@ -892,7 +892,7 @@ suite('protocols', function () {
 
     });
 
-    suite('stateless', function () {
+    describe('stateless', function () {
 
       run(function (emitterPtcl, listenerPtcl, cb) {
         cb(emitterPtcl.createEmitter(writableFactory));
@@ -915,7 +915,7 @@ suite('protocols', function () {
 
     function run(setupFn) {
 
-      test('single', function (done) {
+      it('single', function (done) {
         var ptcl = createProtocol({
           protocol: 'Math',
           messages: {
@@ -940,7 +940,7 @@ suite('protocols', function () {
         });
       });
 
-      test('invalid request', function (done) {
+      it('invalid request', function (done) {
         var ptcl = createProtocol({
           protocol: 'Math',
           messages: {
@@ -959,7 +959,7 @@ suite('protocols', function () {
         });
       });
 
-      test('error response', function (done) {
+      it('error response', function (done) {
         var msg = 'must be non-negative';
         var ptcl = createProtocol({
           protocol: 'Math',
@@ -989,7 +989,7 @@ suite('protocols', function () {
         });
       });
 
-      test('invalid response', function (done) {
+      it('invalid response', function (done) {
         var ptcl = createProtocol({
           protocol: 'Math',
           messages: {
@@ -1019,7 +1019,7 @@ suite('protocols', function () {
         });
       });
 
-      test('invalid error', function (done) {
+      it('invalid error', function (done) {
         var ptcl = createProtocol({
           protocol: 'Math',
           messages: {
@@ -1048,7 +1048,7 @@ suite('protocols', function () {
         });
       });
 
-      test('out of order', function (done) {
+      it('out of order', function (done) {
         var ptcl = createProtocol({
           protocol: 'Delay',
           messages: {
@@ -1091,7 +1091,7 @@ suite('protocols', function () {
         });
       });
 
-      test('compatible protocols', function (done) {
+      it('compatible protocols', function (done) {
         var emitterPtcl = createProtocol({
           protocol: 'emitterProtocol',
           messages: {
@@ -1134,7 +1134,7 @@ suite('protocols', function () {
         );
       });
 
-      test('cached compatible protocols', function (done) {
+      it('cached compatible protocols', function (done) {
         var ptcl1 = createProtocol({
           protocol: 'emitterProtocol',
           messages: {
@@ -1181,7 +1181,7 @@ suite('protocols', function () {
         );
       });
 
-      test('incompatible protocols', function (done) {
+      it('incompatible protocols', function (done) {
         var emitterPtcl = createProtocol({
           protocol: 'emitterProtocol',
           messages: {
@@ -1207,7 +1207,7 @@ suite('protocols', function () {
         );
       });
 
-      test('unknown message', function (done) {
+      it('unknown message', function (done) {
         var ptcl = createProtocol({protocol: 'Empty'});
         setupFn(ptcl, ptcl, function (ee) {
           ptcl.emit('echo', {}, ee, function (err) {
@@ -1217,7 +1217,7 @@ suite('protocols', function () {
         });
       });
 
-      test('unsupported message', function (done) {
+      it('unsupported message', function (done) {
         var ptcl = createProtocol({
           protocol: 'Echo',
           messages: {
@@ -1235,7 +1235,7 @@ suite('protocols', function () {
         });
       });
 
-      test('destroy emitter noWait', function (done) {
+      it('destroy emitter noWait', function (done) {
         var ptcl = createProtocol({
           protocol: 'Delay',
           messages: {
@@ -1270,7 +1270,7 @@ suite('protocols', function () {
         });
       });
 
-      test('destroy emitter', function (done) {
+      it('destroy emitter', function (done) {
         var ptcl = createProtocol({
           protocol: 'Math',
           messages: {
@@ -1298,7 +1298,7 @@ suite('protocols', function () {
 
   });
 
-  test('throw error', function () {
+  it('throw error', function () {
     assert(!tryCatch(null));
     assert.equal(tryCatch(new Error('hi')), 'hi');
     assert.equal(tryCatch('hi'), 'hi');
